@@ -270,6 +270,15 @@ class AmiPipelineLib(
     ) -> None:
         jsii.set(self, "codepipeline", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="diskSize")
+    def disk_size(self) -> typing.Optional[jsii.Number]:
+        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "diskSize"))
+
+    @disk_size.setter
+    def disk_size(self, value: typing.Optional[jsii.Number]) -> None:
+        jsii.set(self, "diskSize", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="distributionConfig")
     def distribution_config(
